@@ -16,10 +16,16 @@
 """Ubuntu Single Sign On client code."""
 
 # constants
-DBUS_PATH_AUTH = "/"
 DBUS_BUS_NAME = "com.ubuntu.sso"
-DBUS_PATH = "/sso"
-DBUS_CRED_PATH = "/credentials"
+DBUS_PATH = "/sso"  # deprecated!
+DBUS_CRED_PATH = "/credentials"  # deprecated!
+DBUS_ACCOUNT_PATH = "/com/ubuntu/sso/accounts"
+
 DBUS_IFACE_AUTH_NAME = "com.ubuntu.sso"
 DBUS_IFACE_USER_NAME = "com.ubuntu.sso.UserManagement"
 DBUS_IFACE_CRED_NAME = "com.ubuntu.sso.ApplicationCredentials"
+
+DBUS_CREDENTIALS_PATH = "/com/ubuntu/sso/credentials"
+DBUS_CREDENTIALS_IFACE = "com.ubuntu.sso.CredentialsManagement"
+
+NO_OP = lambda *args, **kwargs: None
