@@ -29,9 +29,7 @@ import webbrowser
 from functools import wraps
 
 import dbus
-import gettext
 import gtk
-import xdg
 
 from dbus.mainloop.glib import DBusGMainLoop
 from twisted.internet.defer import inlineCallbacks
@@ -39,15 +37,12 @@ from twisted.internet.defer import inlineCallbacks
 from ubuntu_sso import (DBUS_ACCOUNT_PATH, DBUS_BUS_NAME, DBUS_IFACE_USER_NAME,
     NO_OP)
 from ubuntu_sso.logger import setup_logging
-
+from ubuntu_sso.utils.ui import get_data_file, _
 
 # Instance of 'UbuntuSSOClientGUI' has no 'yyy' member
 # pylint: disable=E1101
 
 
-_ = gettext.gettext
-gettext.textdomain('ubuntu-sso-client')
-
 DBusGMainLoop(set_as_default=True)
 logger = setup_logging('ubuntu_sso.gui')
 
@@ -73,38 +68,6 @@ HELP_TEXT_COLOR = gtk.gdk.Color("#bfbfbf")
 WARNING_TEXT_COLOR = gtk.gdk.Color("red")
 
 
-def get_data_dir():
-    """Build absolute path to  the 'data' directory."""
-    module = os.path.dirname(__file__)
-    result = os.path.abspath(os.path.join(module, os.pardir,
-                                          os.pardir, 'data'))
-    logger.debug('get_data_file: trying to load from %r (exists? %s)',
-                 result, os.path.exists(result))
-    if os.path.exists(result):
-        logger.info('get_data_file: returning data dir located at %r.', result)
-        return result
-
-    # no local data dir, looking within system data dirs
-    data_dirs = xdg.BaseDirectory.xdg_data_dirs
-    for path in data_dirs:
-        result = os.path.join(path, 'ubuntu-sso-client', 'data')
-        result = os.path.abspath(result)
-        logger.debug('get_data_file: trying to load from %r (exists? %s)',
-                     result, os.path.exists(result))
-        if os.path.exists(result):
-            logger.info('get_data_file: data dir located at %r.', result)
-            return result
-    else:
-        msg = 'get_data_file: can not build a valid data path. Giving up.' \
-              '__file__ is %r, data_dirs are %r'
-        logger.error(msg, __file__, data_dirs)
-
-
-def get_data_file(filename):
-    """Build absolute path to 'filename' within the 'data' directory."""
-    return os.path.join(get_data_dir(), filename)
-
-
 def log_call(f):
     """Decorator to log call funtions."""
 
@@ -265,7 +228,7 @@ class UbuntuSSOClientGUI(object):
         self.user_email = None
         self.user_password = None
 
-        ui_filename = get_data_file('ui.glade')
+        ui_filename = get_data_file('gtk', 'ui.glade')
         builder = gtk.Builder()
         builder.add_from_file(ui_filename)
         builder.connect_signals(self)
@@ -1064,7 +1027,7 @@ class UbuntuSSOClientGUI(object):
 
     @log_call
     def on_user_registration_error(self, app_name, error, *args, **kwargs):
-        """Captcha image generation failed."""
+        """Error in the data provided for registration."""
         msg = error.get('email')
         if msg is not None:
             self.email1_entry.set_warning(msg)
