@@ -29,6 +29,7 @@ import dbus
 import gtk
 import webkit
 
+from twisted.internet import defer
 from twisted.trial.unittest import TestCase
 from ubuntuone.devtools.handlers import MementoHandler
 
@@ -157,18 +158,16 @@ class FakedEmbeddedBrowser(gtk.TextView):
 class BasicTestCase(TestCase):
     """Test case with a helper tracker."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
+        yield super(BasicTestCase, self).setUp()
         self._called = False  # helper
 
         self.memento = MementoHandler()
         self.memento.setLevel(logging.DEBUG)
         gui.logger.addHandler(self.memento)
 
-    def tearDown(self):
-        """Clean up."""
-        self._called = False
-
     def _set_called(self, *args, **kwargs):
         """Set _called to True."""
         self._called = (args, kwargs)
@@ -177,9 +176,10 @@ class BasicTestCase(TestCase):
 class LabeledEntryTestCase(BasicTestCase):
     """Test suite for the labeled entry."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(LabeledEntryTestCase, self).setUp()
+        yield super(LabeledEntryTestCase, self).setUp()
         self.label = 'Test me please'
         self.entry = gui.LabeledEntry(label=self.label)
 
@@ -188,11 +188,6 @@ class LabeledEntryTestCase(BasicTestCase):
         window.add(self.entry)
         window.show_all()
 
-    def tearDown(self):
-        """Clean up."""
-        self.entry = None
-        super(LabeledEntryTestCase, self).tearDown()
-
     def grab_focus(self, focus_in=True):
         """Grab focus on widget, if None use self.entry."""
         direction = 'in' if focus_in else 'out'
@@ -351,9 +346,10 @@ class LabeledEntryTestCase(BasicTestCase):
 class PasswordLabeledEntryTestCase(LabeledEntryTestCase):
     """Test suite for the labeled entry when is_password is True."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(PasswordLabeledEntryTestCase, self).setUp()
+        yield super(PasswordLabeledEntryTestCase, self).setUp()
         self.entry.is_password = True
 
     def test_password_fields_are_visible_at_startup(self):
@@ -381,9 +377,10 @@ class UbuntuSSOClientTestCase(BasicTestCase):
     gui_class = gui.UbuntuSSOClientGUI
     kwargs = dict(app_name=APP_NAME, tc_url=TC_URL, help_text=HELP_TEXT)
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(UbuntuSSOClientTestCase, self).setUp()
+        yield super(UbuntuSSOClientTestCase, self).setUp()
         self.patch(dbus, 'SessionBus', FakedSessionBus)
         self.patch(dbus, 'Interface', FakedSSOBackend)
         self.pages = ('enter_details', 'processing', 'verify_email', 'finish',
@@ -392,11 +389,11 @@ class UbuntuSSOClientTestCase(BasicTestCase):
         self.ui = self.gui_class(**self.kwargs)
         self.error = {'message': self.ui.UNKNOWN_ERROR}
 
+    @defer.inlineCallbacks
     def tearDown(self):
-        """Clean up."""
         self.ui.bus.callbacks = {}
         self.ui = None
-        super(UbuntuSSOClientTestCase, self).tearDown()
+        yield super(UbuntuSSOClientTestCase, self).tearDown()
 
     def assert_entries_are_packed_to_ui(self, container_name, entries):
         """Every entry is properly packed in the ui 'container_name'."""
@@ -909,8 +906,9 @@ class TermsAndConditionsTestCase(UbuntuSSOClientTestCase):
 class TermsAndConditionsBrowserTestCase(UbuntuSSOClientTestCase):
     """Test suite for the terms & conditions browser."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(TermsAndConditionsBrowserTestCase, self).setUp()
+        yield super(TermsAndConditionsBrowserTestCase, self).setUp()
         self.patch(webkit, 'WebView', FakedEmbeddedBrowser)
 
         self.ui.tc_button.clicked()
@@ -918,9 +916,10 @@ class TermsAndConditionsBrowserTestCase(UbuntuSSOClientTestCase):
         assert len(children) == 1
         self.browser = children[0]
 
+    @defer.inlineCallbacks
     def tearDown(self):
         self.ui.tc_browser_vbox.hide()
-        super(TermsAndConditionsBrowserTestCase, self).tearDown()
+        yield super(TermsAndConditionsBrowserTestCase, self).tearDown()
 
     def test_tc_browser_is_created_when_tc_page_is_shown(self):
         """The browser is created when the TC button is clicked."""
@@ -1066,9 +1065,10 @@ class TermsAndConditionsBrowserTestCase(UbuntuSSOClientTestCase):
 class RegistrationErrorTestCase(UbuntuSSOClientTestCase):
     """Test suite for the user registration error handling."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(RegistrationErrorTestCase, self).setUp()
+        yield super(RegistrationErrorTestCase, self).setUp()
         self.click_join_with_valid_data()
 
     def test_previous_page_is_shown(self):
@@ -1113,9 +1113,10 @@ class RegistrationErrorTestCase(UbuntuSSOClientTestCase):
 class VerifyEmailTestCase(UbuntuSSOClientTestCase):
     """Test suite for the user registration (verify email page)."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(VerifyEmailTestCase, self).setUp()
+        yield super(VerifyEmailTestCase, self).setUp()
         self.ui.on_user_registered(app_name=APP_NAME, email=EMAIL)
         self.click_verify_email_with_valid_data()
 
@@ -1257,9 +1258,10 @@ class VerifyEmailTestCase(UbuntuSSOClientTestCase):
 class VerifyEmailValidationTestCase(UbuntuSSOClientTestCase):
     """Test suite for the user registration validation (verify email page)."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(VerifyEmailValidationTestCase, self).setUp()
+        yield super(VerifyEmailValidationTestCase, self).setUp()
         self.ui.on_user_registered(app_name=APP_NAME, email=EMAIL)
 
     def test_warning_is_shown_if_empty_email_token(self):
@@ -1307,9 +1309,10 @@ class VerifyEmailValidationLoginOnlyTestCase(VerifyEmailValidationTestCase):
 class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
     """Test suite for the user registration  validations."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(RegistrationValidationTestCase, self).setUp()
+        yield super(RegistrationValidationTestCase, self).setUp()
         self.ui.join_ok_button.set_sensitive(True)
 
     def test_warning_is_shown_if_name_empty(self):
@@ -1440,9 +1443,10 @@ class RegistrationValidationTestCase(UbuntuSSOClientTestCase):
 class LoginTestCase(UbuntuSSOClientTestCase):
     """Test suite for the user login pages."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(LoginTestCase, self).setUp()
+        yield super(LoginTestCase, self).setUp()
         self.ui.login_button.clicked()
 
     def test_login_button_clicked_morphs_to_login_page(self):
@@ -1592,9 +1596,10 @@ class LoginTestCase(UbuntuSSOClientTestCase):
 class LoginValidationTestCase(UbuntuSSOClientTestCase):
     """Test suite for the user login validation."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(LoginValidationTestCase, self).setUp()
+        yield super(LoginValidationTestCase, self).setUp()
         self.ui.login_button.clicked()
 
     def test_warning_is_shown_if_empty_email(self):
@@ -1648,9 +1653,10 @@ class LoginValidationTestCase(UbuntuSSOClientTestCase):
 class ResetPasswordTestCase(UbuntuSSOClientTestCase):
     """Test suite for the reset password functionality."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(ResetPasswordTestCase, self).setUp()
+        yield super(ResetPasswordTestCase, self).setUp()
         self.ui.login_button.clicked()
         self.ui.forgotten_password_button.clicked()
 
@@ -1812,9 +1818,10 @@ class ResetPasswordValidationTestCase(UbuntuSSOClientTestCase):
 class SetNewPasswordTestCase(UbuntuSSOClientTestCase):
     """Test suite for setting a new password functionality."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(SetNewPasswordTestCase, self).setUp()
+        yield super(SetNewPasswordTestCase, self).setUp()
         self.click_request_password_token_with_valid_data()
         self.ui.on_password_reset_token_sent(app_name=APP_NAME, email=EMAIL)
 
@@ -2114,9 +2121,10 @@ class CallbacksTestCase(UbuntuSSOClientTestCase):
     REGISTRATION_SUCCESS = 'registration_success_callback'
     USER_CANCELLATION = 'user_cancellation_callback'
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(CallbacksTestCase, self).setUp()
+        yield super(CallbacksTestCase, self).setUp()
         self._called = {}
         for name in (self.LOGIN_SUCCESSFULL,
                      self.REGISTRATION_SUCCESS,
@@ -2250,9 +2258,10 @@ class CallbacksTestCase(UbuntuSSOClientTestCase):
 class DefaultButtonsTestCase(UbuntuSSOClientTestCase):
     """Each UI page has a default button when visible."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(DefaultButtonsTestCase, self).setUp()
+        yield super(DefaultButtonsTestCase, self).setUp()
         self.mapping = (
             ('enter_details_vbox', 'join_ok_button'),
             ('tc_browser_vbox', 'tc_back_button'),
