@@ -24,12 +24,13 @@ from twisted.trial.unittest import TestCase
 from ubuntu_sso.keyring.windows import Keyring, USERNAME
 
 
-class TestWindowsKeyring(MockerTestCase, TestCase):
+class TestWindowsKeyring(TestCase, MockerTestCase):
     """Test the windows keyring implementation."""
 
+    @inlineCallbacks
     def setUp(self):
         """Setup  tests."""
-        super(TestWindowsKeyring, self).setUp()
+        yield super(TestWindowsKeyring, self).setUp()
         self.keyring_lib = self.mocker.mock()
         self.keyring = Keyring(self.keyring_lib)
 
