@@ -26,7 +26,6 @@ import os
 from mocker import Mocker, MockerTestCase, ARGS, KWARGS, MATCH
 from twisted.internet import defer
 from twisted.internet.defer import Deferred, inlineCallbacks
-from twisted.trial.unittest import TestCase
 from ubuntuone.devtools.handlers import MementoHandler
 
 import ubuntu_sso.keyring
@@ -74,8 +73,10 @@ class SsoDbusTestCase(TestCase):
 
     timeout = 2
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Create the mocking bus."""
+        yield super(SsoDbusTestCase, self).setUp()
         self.mocker = Mocker()
         self.mockbusname = self.mocker.mock()
         mockbus = self.mocker.mock()
@@ -96,10 +97,12 @@ class SsoDbusTestCase(TestCase):
         self.keyring_was_set = False
         self.keyring_values = None
 
+    @defer.inlineCallbacks
     def tearDown(self):
         """Verify the mocking bus and shut it down."""
         self.mocker.verify()
         self.mocker.restore()
+        yield super(SsoDbusTestCase, self).tearDown()
 
     def test_creation(self):
         """Test that the object creation is successful."""
@@ -568,8 +571,9 @@ class ApplicationCredentialsTestCase(TestCase, MockerTestCase):
 
     timeout = 5
 
+    @inlineCallbacks
     def setUp(self):
-        MockerTestCase.setUp(self)
+        yield super(ApplicationCredentialsTestCase, self).setUp()
 
         self.client = SSOCredentials(self.mocker.mock())
 
@@ -611,8 +615,9 @@ class ApplicationCredentialsGUITestCase(TestCase, MockerTestCase):
     app_name = APP_NAME
     ping_url = None
 
+    @inlineCallbacks
     def setUp(self):
-        MockerTestCase.setUp(self)
+        yield super(ApplicationCredentialsGUITestCase, self).setUp()
         self.client = SSOCredentials(self.mocker.mock())
         self.args = {PING_URL_KEY: self.ping_url,
                      TC_URL_KEY: TC_URL, HELP_TEXT_KEY: HELP_TEXT,
@@ -712,8 +717,9 @@ class CredentialsManagementTestCase(TestCase):
                  UI_CLASS_KEY: 'SuperUI', UI_MODULE_KEY: 'foo.bar.baz',
                 }
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(CredentialsManagementTestCase, self).setUp()
+        yield super(CredentialsManagementTestCase, self).setUp()
 
         self.mocker = Mocker()
         self.client = CredentialsManagement(timeout_func=lambda *a: None,
@@ -725,11 +731,12 @@ class CredentialsManagementTestCase(TestCase):
         self.memento.setLevel(logging.DEBUG)
         ubuntu_sso.main.logger.addHandler(self.memento)
 
+    @defer.inlineCallbacks
     def tearDown(self):
         """Verify the mocking stuff and shut it down."""
         self.mocker.verify()
         self.mocker.restore()
-        super(CredentialsManagementTestCase, self).tearDown()
+        yield super(CredentialsManagementTestCase, self).tearDown()
 
     def assert_dbus_method_correct(self, method):
         """Check that 'method' is a dbus method with proper signatures."""
@@ -766,8 +773,9 @@ class FakeCredentials(object):
 class CredentialsManagementRefCountingTestCase(CredentialsManagementTestCase):
     """Tests for the CredentialsManagement ref counting."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(CredentialsManagementRefCountingTestCase, self).setUp()
+        yield super(CredentialsManagementRefCountingTestCase, self).setUp()
         self.patch(ubuntu_sso.main, 'Credentials', FakeCredentials)
 
     def test_ref_counting(self):
@@ -1198,8 +1206,9 @@ class CredentialsManagementStoreTestCase(CredentialsManagementTestCase):
 class CredentialsManagementOpsTestCase(CredentialsManagementTestCase):
     """Tests for the CredentialsManagement login/register methods."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(CredentialsManagementOpsTestCase, self).setUp()
+        yield super(CredentialsManagementOpsTestCase, self).setUp()
         self.args = dict((k, str(v)) for k, v in self.base_args.iteritems())
         self.cred_args = self.base_args.copy()
         self.cred_args[SUCCESS_CB_KEY] = self.client.CredentialsFound
@@ -1237,15 +1246,19 @@ class CredentialsManagementOpsTestCase(CredentialsManagementTestCase):
 class CredentialsManagementParamsTestCase(CredentialsManagementOpsTestCase):
     """Tests for the CredentialsManagement extra parameters handling."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(CredentialsManagementParamsTestCase, self).setUp()
+        yield super(CredentialsManagementParamsTestCase, self).setUp()
         self.args['dummy'] = 'nothing useful'
 
 
 class CredentialsManagementSignalsTestCase(TestCase):
     """Tests for the CredentialsManagement DBus signals."""
 
+    @defer.inlineCallbacks
     def setUp(self):
+        """Set up."""
+        yield super(CredentialsManagementSignalsTestCase, self).setUp()
         self.client = CredentialsManagement(timeout_func=lambda *a: None,
                                             shutdown_func=lambda *a: None)
 
