@@ -87,9 +87,9 @@ class FakeDecoratedObject(object):
 class SignalTestCase(MockerTestCase):
     """Test the signal decorator."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        """Set the tests."""
-        super(SignalTestCase, self).setUp()
+        yield super(SignalTestCase, self).setUp()
         self.fake_object = FakeDecoratedObject()
         self.cb = self.mocker.mock()
 
@@ -201,9 +201,10 @@ class SignalBroadcasterTestCase(TestCase):
 class SSOLoginTestCase(TestCase):
     """Test the login class."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup tests."""
-        super(SSOLoginTestCase, self).setUp()
+        yield super(SSOLoginTestCase, self).setUp()
         self.mocker = Mocker()
         self.root = self.mocker.mock()
         self.except_to_errdict = self.mocker.replace(
@@ -219,13 +220,16 @@ class SSOLoginTestCase(TestCase):
         self.client_factory = PBClientFactory()
         self.connector = reactor.connectTCP(LOCALHOST, port,
                                             self.client_factory)
+        self.client = yield self._get_client()
         # pylint: enable=E1101
 
+    @defer.inlineCallbacks
     def tearDown(self):
         """Clean reactor."""
+        yield super(SSOLoginTestCase, self).tearDown()
         if self.server_factory.protocolInstance is not None:
             self.server_factory.protocolInstance.transport.loseConnection()
-        return defer.gatherResults([self._tearDownServer(),
+        yield defer.gatherResults([self._tearDownServer(),
                                     self._tearDownClient()])
 
     def _tearDownServer(self):
@@ -975,11 +979,13 @@ class CredentialsManagementTestCase(TestCase):
                                             self.client_factory)
         # pylint: enable=E1101
 
+    @defer.inlineCallbacks
     def tearDown(self):
         """Clean reactor."""
+        yield super(CredentialsManagementTestCase, self).tearDown()
         if self.server_factory.protocolInstance is not None:
             self.server_factory.protocolInstance.transport.loseConnection()
-        return defer.gatherResults([self._tearDownServer(),
+        yield defer.gatherResults([self._tearDownServer(),
                                     self._tearDownClient()])
 
     def _tearDownServer(self):
