@@ -16,6 +16,7 @@
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Test the ui controllers."""
 
+from twisted.internet import defer
 from twisted.trial.unittest import TestCase
 
 from mocker import ANY, MATCH, MockerTestCase
@@ -76,9 +77,10 @@ from ubuntu_sso.utils.ui import (
 class ChooseSignInControllerTestCase(MockerTestCase):
     """Test the choose sign in controller."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set tests."""
-        super(ChooseSignInControllerTestCase, self).setUp()
+        yield super(ChooseSignInControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.controller = ChooseSignInController()
@@ -139,9 +141,10 @@ class ChooseSignInControllerTestCase(MockerTestCase):
 class CurrentUserControllerTestCase(MockerTestCase):
     """Test the current user controller."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup tests."""
-        super(CurrentUserControllerTestCase, self).setUp()
+        yield super(CurrentUserControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.connect = self.mocker.mock()
@@ -269,9 +272,10 @@ class CurrentUserControllerErrorTestCase(TestCase):
     on_error_method_name = "on_login_error"
     controller_class = CurrentUserController
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup test."""
-        super(CurrentUserControllerErrorTestCase, self).setUp()
+        yield super(CurrentUserControllerErrorTestCase, self).setUp()
         self.message_box = FakeMessageBox()
         self.controller = self.controller_class(
             message_box=self.message_box)
@@ -326,9 +330,10 @@ class EmailVerificationControllerErrorTestCase(
     on_error_method_name = "on_email_validation_error"
     controller_class = EmailVerificationController
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup test."""
-        super(EmailVerificationControllerErrorTestCase, self).setUp()
+        yield super(EmailVerificationControllerErrorTestCase, self).setUp()
         # This error handler takes one extra argument.
         self.on_error_method = lambda error: getattr(
             self.controller, self.on_error_method_name)('APP', error)
@@ -342,9 +347,10 @@ class SetUpAccountControllerErrorTestCase(
     on_error_method_name = "on_user_registration_error"
     controller_class = SetUpAccountController
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup test."""
-        super(SetUpAccountControllerErrorTestCase, self).setUp()
+        yield super(SetUpAccountControllerErrorTestCase, self).setUp()
         self.patch(self.controller, "_refresh_captcha", lambda *args: None)
 
 
@@ -361,9 +367,10 @@ class CurrentUserControllerValidationTest(TestCase):
 
     """Tests for CurrentUserController, but without Mocker."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup test."""
-        super(CurrentUserControllerValidationTest, self).setUp()
+        yield super(CurrentUserControllerValidationTest, self).setUp()
         self.message_box = FakeMessageBox()
         self.controller = CurrentUserController(
             message_box=self.message_box)
@@ -406,9 +413,10 @@ class CurrentUserControllerValidationTest(TestCase):
 class SetUpAccountControllerTestCase(MockerTestCase):
     """test the controller used to setup a new account."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set the different tests."""
-        super(SetUpAccountControllerTestCase, self).setUp()
+        yield super(SetUpAccountControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.get_password_strength = self.mocker.replace(
@@ -672,7 +680,6 @@ class FakeMessageBox(object):
 
 
 class FakeView(object):
-
     """A fake view."""
 
     app_name = "TestApp"
@@ -683,12 +690,12 @@ class FakeView(object):
 
 
 class SetupAccountControllerValidationTest(TestCase):
+    """Tests for validating the account setup controller."""
 
-    """Tests for SetupAccountController, but without Mocker."""
-
+    @defer.inlineCallbacks
     def setUp(self):
         """Set the different tests."""
-        super(SetupAccountControllerValidationTest, self).setUp()
+        yield super(SetupAccountControllerValidationTest, self).setUp()
         self.message_box = FakeMessageBox()
         self.controller = SetUpAccountController(message_box=self.message_box)
         self.patch(self.controller, '_refresh_captcha', self._set_called)
@@ -754,9 +761,10 @@ class TosControllerTestCase(MockerTestCase):
 class EmailVerificationControllerTestCase(MockerTestCase):
     """Test the controller."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set tests."""
-        super(EmailVerificationControllerTestCase, self).setUp()
+        yield super(EmailVerificationControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.controller = EmailVerificationController(
@@ -816,9 +824,11 @@ class EmailVerificationControllerTestCase(MockerTestCase):
 class EmailVerificationControllerValidationTestCase(TestCase):
     """Tests for EmailVerificationController, but without Mocker."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set the different tests."""
-        super(EmailVerificationControllerValidationTestCase, self).setUp()
+        yield super(EmailVerificationControllerValidationTestCase,
+            self).setUp()
         self.message_box = FakeMessageBox()
         self.controller = EmailVerificationController(
             message_box=self.message_box)
@@ -837,9 +847,10 @@ class EmailVerificationControllerValidationTestCase(TestCase):
 class ErrorControllerTestCase(MockerTestCase):
     """Test the success page controller."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set the tests."""
-        super(ErrorControllerTestCase, self).setUp()
+        yield super(ErrorControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.controller = ErrorController()
@@ -870,9 +881,10 @@ class ErrorControllerTestCase(MockerTestCase):
 class SuccessControllerTestCase(MockerTestCase):
     """Test the success page controller."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set the tests."""
-        super(SuccessControllerTestCase, self).setUp()
+        yield super(SuccessControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.controller = SuccessController()
@@ -903,9 +915,10 @@ class SuccessControllerTestCase(MockerTestCase):
 class UbuntuSSOWizardControllerTestCase(MockerTestCase):
     """Test the wizard controller."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set tests."""
-        super(UbuntuSSOWizardControllerTestCase, self).setUp()
+        yield super(UbuntuSSOWizardControllerTestCase, self).setUp()
         self.app_name = 'test'
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
@@ -1022,9 +1035,10 @@ class ForgottenPasswordControllerValidationTest(TestCase):
 
     """Tests for ForgottenPasswordController, but without Mocker."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Set the different tests."""
-        super(ForgottenPasswordControllerValidationTest, self).setUp()
+        yield super(ForgottenPasswordControllerValidationTest, self).setUp()
         self.message_box = FakeMessageBox()
         self.controller = ForgottenPasswordController(
             message_box=self.message_box)
@@ -1061,9 +1075,10 @@ class ForgottenPasswordControllerValidationTest(TestCase):
 class ForgottenPasswordControllerTestCase(MockerTestCase):
     """Test the controller of the fogotten password page."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup the tests."""
-        super(ForgottenPasswordControllerTestCase, self).setUp()
+        yield super(ForgottenPasswordControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.controller = ForgottenPasswordController()
@@ -1154,9 +1169,10 @@ class ForgottenPasswordControllerTestCase(MockerTestCase):
 class ResetPasswordControllerTestCase(MockerTestCase):
     """Ensure that the reset password works as expected."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup the tests."""
-        super(ResetPasswordControllerTestCase, self).setUp()
+        yield super(ResetPasswordControllerTestCase, self).setUp()
         self.view = self.mocker.mock()
         self.backend = self.mocker.mock()
         self.controller = ResetPasswordController()
@@ -1275,9 +1291,10 @@ class ResetPasswordControllerValidationTest(TestCase):
 
     """Tests for ResetPasswordController, but without Mocker."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Setup test."""
-        super(ResetPasswordControllerValidationTest, self).setUp()
+        yield super(ResetPasswordControllerValidationTest, self).setUp()
         self.controller = ResetPasswordController()
         self.controller.view = FakeResetPasswordPage()
         self._called = False
