@@ -18,6 +18,7 @@
 
 import os
 
+from twisted.internet import defer
 from twisted.trial import unittest
 
 from ubuntu_sso.keyring import get_token_name
@@ -52,8 +53,9 @@ WINDOW_ID = 5
 class TestCase(unittest.TestCase):
     """Customized test case that keeps tracks of method calls."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(TestCase, self).setUp()
+        yield super(TestCase, self).setUp()
         self._called = False
 
     def _set_called(self, *args, **kwargs):
