@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 #
 # Author: Natalia Bidart <natalia.bidart@canonical.com>
+# Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010, 2011 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -23,15 +24,37 @@ import os
 # pylint: disable=F0401
 from lazr.restfulclient.errors import HTTPError
 # pylint: enable=F0401
+from oauth import oauth
 from twisted.trial.unittest import TestCase
+from twisted.internet import defer
 
-from ubuntu_sso.account import (Account, AuthenticationError, EmailTokenError,
-    InvalidEmailError, InvalidPasswordError, NewPasswordError, SERVICE_URL,
-    RegistrationError, ResetPasswordTokenError,
-    SSO_STATUS_OK, SSO_STATUS_ERROR)
-from ubuntu_sso.tests import (APP_NAME, CAPTCHA_ID, CAPTCHA_PATH,
-    CAPTCHA_SOLUTION, EMAIL, EMAIL_TOKEN, NAME, PASSWORD, RESET_PASSWORD_TOKEN,
-    TOKEN, TOKEN_NAME)
+from ubuntu_sso.account import (
+    Account,
+    AuthenticationError,
+    EmailTokenError,
+    InvalidEmailError,
+    InvalidPasswordError,
+    NewPasswordError,
+    SERVICE_URL,
+    RegistrationError,
+    ResetPasswordTokenError,
+    SSO_STATUS_OK,
+    SSO_STATUS_ERROR,
+    TimestampedAuthorizer,
+)
+from ubuntu_sso.tests import (
+    APP_NAME,
+    CAPTCHA_ID,
+    CAPTCHA_PATH,
+    CAPTCHA_SOLUTION,
+    EMAIL,
+    EMAIL_TOKEN,
+    NAME,
+    PASSWORD,
+    RESET_PASSWORD_TOKEN,
+    TOKEN,
+    TOKEN_NAME,
+)
 
 
 CANT_RESET_PASSWORD_CONTENT = "CanNotResetPassowrdError: " \
@@ -144,11 +167,43 @@ class FakedSSOServer(object):
         self.accounts = FakedAccounts()
 
 
+class TimestampedAuthorizerTestCase(TestCase):
+    """Test suite for the TimestampedAuthorizer."""
+
+    def test_authorize_request_includes_timestamp(self):
+        """The authorizeRequest method includes the timestamp."""
+        fromcandt_call = []
+        fake_uri = "http://protocultura.net"
+        fake_timestamp = 1234
+        get_fake_timestamp = lambda: fake_timestamp
+        original_oauthrequest = oauth.OAuthRequest
+
+        class FakeOAuthRequest(oauth.OAuthRequest):
+            """A Fake OAuthRequest class."""
+
+            @staticmethod
+            def from_consumer_and_token(*args, **kwargs):
+                """A fake from_consumer_and_token."""
+                fromcandt_call.append((args, kwargs))
+                builder = original_oauthrequest.from_consumer_and_token
+                return builder(*args, **kwargs)
+
+        self.patch(oauth, "OAuthRequest", FakeOAuthRequest)
+
+        authorizer = TimestampedAuthorizer(get_fake_timestamp, "ubuntuone")
+        authorizer.authorizeRequest(fake_uri, "POST", None, {})
+        call_kwargs = fromcandt_call[0][1]
+        parameters = call_kwargs["parameters"]
+        self.assertEqual(parameters["oauth_timestamp"], fake_timestamp)
+
+
 class AccountTestCase(TestCase):
     """Test suite for the SSO login processor."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
+        yield super(AccountTestCase, self).setUp()
         self.processor = Account(sso_service_class=FakedSSOServer)
         self.register_kwargs = dict(email=EMAIL, password=PASSWORD,
                                     displayname=NAME,
@@ -157,8 +212,10 @@ class AccountTestCase(TestCase):
         self.login_kwargs = dict(email=EMAIL, password=PASSWORD,
                                  token_name=TOKEN_NAME)
 
+    @defer.inlineCallbacks
     def tearDown(self):
-        """Clean up."""
+        """Tear down."""
+        yield super(AccountTestCase, self).tearDown()
         self.processor = None
 
     def test_generate_captcha(self):
