@@ -3,7 +3,7 @@
 # Author: Natalia Bidart <natalia.bidart@canonical.com>
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010, 2011 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -20,6 +20,7 @@
 
 import logging
 import os
+import time
 import urllib2
 
 from twisted.internet import defer
@@ -102,18 +103,16 @@ class FakedSSOLoginRoot(object):
 class BasicTestCase(TestCase):
     """Test case with a helper tracker."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
+        yield super(BasicTestCase, self).setUp()
         self._called = False  # helper
 
         self.memento = MementoHandler()
         self.memento.setLevel(logging.DEBUG)
         credentials.logger.addHandler(self.memento)
 
-    def tearDown(self):
-        """Clean up."""
-        self._called = False
-
     def _set_called(self, *args, **kwargs):
         """Set _called to True."""
         self._called = (args, kwargs)
@@ -122,9 +121,10 @@ class BasicTestCase(TestCase):
 class CredentialsTestCase(BasicTestCase):
     """Test suite for the Credentials class."""
 
+    @defer.inlineCallbacks
     def setUp(self):
         """Init."""
-        super(CredentialsTestCase, self).setUp()
+        yield super(CredentialsTestCase, self).setUp()
         self.obj = credentials.Credentials(success_cb=self.success,
                                            error_cb=self.error,
                                            denial_cb=self.denial,
@@ -359,8 +359,9 @@ class CredentialsAuthDeniedTestCase(CredentialsTestCase):
 class PingUrlTestCase(CredentialsTestCase):
     """Test suite for the URL pinging."""
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(PingUrlTestCase, self).setUp()
+        yield super(PingUrlTestCase, self).setUp()
         self._request = None
 
         def faked_urlopen(request):
@@ -373,6 +374,8 @@ class PingUrlTestCase(CredentialsTestCase):
             return response
 
         self.patch(credentials.urllib2, 'urlopen', faked_urlopen)
+        self.patch(credentials.utils.timestamp_checker, "get_faithful_time",
+                   time.time)
 
     @defer.inlineCallbacks
     def test_ping_url_if_url_is_none(self):
@@ -549,8 +552,9 @@ class RegisterTestCase(CredentialsTestCase):
     kwargs = {}
     inner_class = FakedClientGUI
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(RegisterTestCase, self).setUp()
+        yield super(RegisterTestCase, self).setUp()
         self.inner_kwargs = UI_KWARGS.copy()
         self.inner_kwargs['login_only'] = self.login_only
         self.method_call = getattr(self.obj, self.operation)
@@ -646,8 +650,9 @@ class LoginEmailPasswordTestCase(RegisterTestCase):
     kwargs = {'email': EMAIL, 'password': PASSWORD}
     inner_class = FakedSSOLoginRoot
 
+    @defer.inlineCallbacks
     def setUp(self):
-        super(LoginEmailPasswordTestCase, self).setUp()
+        yield super(LoginEmailPasswordTestCase, self).setUp()
         self.inner_kwargs = {APP_NAME_KEY: APP_NAME, 'email': EMAIL,
                              'password': PASSWORD,
                              'result_cb': self.obj._login_success_cb,
