@@ -394,8 +394,9 @@ class BaseTestCase(DBusTestCase):
     timeout = 10
     secret_service_class = SecretServiceMock
 
+    @inlineCallbacks
     def setUp(self):
-        super(BaseTestCase, self).setUp()
+        yield super(BaseTestCase, self).setUp()
         self.session_bus = dbus.SessionBus()
         self.mock_service = self.dbus_publish(txsecrets.SECRETS_SERVICE,
                                               self.secret_service_class)
